@@ -3,7 +3,7 @@
 |''Description''|adaptor for interacting with TiddlyWeb|
 |''Author:''|FND|
 |''Contributors''|Chris Dent, Martin Budden|
-|''Version''|1.4.6|
+|''Version''|1.4.7|
 |''Status''|stable|
 |''Source''|http://svn.tiddlywiki.org/Trunk/association/adaptors/TiddlyWebAdaptor.js|
 |''CodeRepository''|http://svn.tiddlywiki.org/Trunk/association/|
@@ -320,6 +320,8 @@ adaptor.putTiddlerCallback = function(status, context, responseText, uri, xhr) {
 			var bag = loc.split("/bags/").pop().split("/")[0];
 			context.tiddler.fields["server.bag"] = bag;
 			context.tiddler.fields["server.workspace"] = "bags/" + bag;
+			var rev = etag.split("/").pop().split(";")[0];
+			context.tiddler.fields["server.page.revision"] = rev;
 			context.tiddler.fields["server.etag"] = etag;
 			if(context.callback) {
 				context.callback(context, context.userParams);
